@@ -353,7 +353,7 @@ def general_objs(request, Obj, ObjForm, fields=(), query_dict={}, query_term='',
 
 
 def general_obj(request, Obj, ObjForm, general_obj_id, fields=(), \
-        template=False, html_scripts=False, *args, **kwargs):
+        template=False, html_scripts=False, translations={}, *args, **kwargs):
     """General view for displaying a detailed view of an object"""
     if not template:
         template = 'generalobj.html'
@@ -368,7 +368,11 @@ def general_obj(request, Obj, ObjForm, general_obj_id, fields=(), \
     if fields:
         ret_dic['fields'] = []
         for field in fields:
-            ret_dic['fields'].append((field, getattr(obj, field)))
+            field_name = field
+            if field in translations:
+                field_name = translations[field]
+            ret_dic['fields'].append((field_name, getattr(obj, field)))
+    print(ret_dic['fields'])
     ret_dic['url_edit'] = reverse('%s_edit' % ret_dic['class_name'].lower(), \
             args=(obj.id,))
     if 'additional_tabs' in kwargs:
@@ -380,7 +384,8 @@ def general_obj(request, Obj, ObjForm, general_obj_id, fields=(), \
 
 
 def general_obj_search(request, Obj, ObjForm, search_fields=(), \
-        result_fields=(), template=False, *args, **kwargs):
+        result_fields=(), template=False, allow_prompt_ajax_search=False, \
+        relational_obj_values={}, translations={}, *args, **kwargs):
     if not template:
         template = 'generalobj_search.html'
     ret_dic = {}
@@ -388,10 +393,11 @@ def general_obj_search(request, Obj, ObjForm, search_fields=(), \
             ret_dic['ajax_url'], ret_dic['charfield_exists'], \
             ret_dic['datetimefield_exists'], ret_dic['booleanfield_exists']) = \
             get_params_for_search(request, Obj, ObjForm, search_fields, \
-            result_fields)
+            result_fields, relational_obj_values, translations)
     if 'passing_scripts' in kwargs:
         ret_dic['passing_scripts'] = kwargs['passing_scripts']
     ret_dic['url_new'] = reverse('%s_new' % ret_dic['class_name'].lower())
+    ret_dic['allow_prompt_ajax_search'] = allow_prompt_ajax_search
     return render(request, template, ret_dic)
 
 
@@ -416,6 +422,9 @@ def ajax_get_general_obj_list(request, Obj, ObjForm, search_fields=(), \
                     '%s_lt' % field[0], '')
         elif field[2] == 'text':
             get_fields[field[0]] = request.GET.get(field[0], '').strip()
+        elif field[2] == 'relation':
+            get_fields[field[0]] = \
+                    request.GET.get(field[0], '').strip().split(',')
     print('gf = ', get_fields)
     useful_data_available = False
     useful_data_available = any([item[1] for item in get_fields.items()])
@@ -449,6 +458,9 @@ def ajax_get_general_obj_list(request, Obj, ObjForm, search_fields=(), \
                         dt[field[0]] = True
                     else:
                         dt[field[0]] = False
+            elif field[1] == 'relation':
+                if any(get_fields[field[0]]):
+                    dt['%s__id__in' % field[0]] = get_fields[field[0]]
         ret_dic['objects'] = Obj.objects.filter(**dt)
         print('dt = %s' % dt)
     else:
